package com.zjsgfa.project.zjsgfa.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.zjsgfa.project.zjsgfa.mapper.SjLjzjysyqkMapper;
import com.zjsgfa.project.zjsgfa.domain.SjLjzjysyqk;
import com.zjsgfa.project.zjsgfa.service.ISjLjzjysyqkService;

/**
 * 邻井钻井液使用情况Service业务层处理
 * 
 * @author ruoyi
 * @date 2026-02-04
 */
@Service
public class SjLjzjysyqkServiceImpl implements ISjLjzjysyqkService 
{
    @Autowired
    private SjLjzjysyqkMapper sjLjzjysyqkMapper;

    /**
     * 查询邻井钻井液使用情况
     * 
     * @param id 邻井钻井液使用情况主键
     * @return 邻井钻井液使用情况
     */
    @Override
    public SjLjzjysyqk selectSjLjzjysyqkById(Long id)
    {
        return sjLjzjysyqkMapper.selectSjLjzjysyqkById(id);
    }

    /**
     * 查询邻井钻井液使用情况列表
     * 
     * @param sjLjzjysyqk 邻井钻井液使用情况
     * @return 邻井钻井液使用情况
     */
    @Override
    public List<SjLjzjysyqk> selectSjLjzjysyqkList(SjLjzjysyqk sjLjzjysyqk)
    {
        return sjLjzjysyqkMapper.selectSjLjzjysyqkList(sjLjzjysyqk);
    }

    /**
     * 新增邻井钻井液使用情况
     * 
     * @param sjLjzjysyqk 邻井钻井液使用情况
     * @return 结果
     */
    @Override
    public int insertSjLjzjysyqk(SjLjzjysyqk sjLjzjysyqk)
    {
        return sjLjzjysyqkMapper.insertSjLjzjysyqk(sjLjzjysyqk);
    }

    /**
     * 修改邻井钻井液使用情况
     * 
     * @param sjLjzjysyqk 邻井钻井液使用情况
     * @return 结果
     */
    @Override
    public int updateSjLjzjysyqk(SjLjzjysyqk sjLjzjysyqk)
    {
        return sjLjzjysyqkMapper.updateSjLjzjysyqk(sjLjzjysyqk);
    }

    /**
     * 批量删除邻井钻井液使用情况
     * 
     * @param ids 需要删除的邻井钻井液使用情况主键
     * @return 结果
     */
    @Override
    public int deleteSjLjzjysyqkByIds(Long[] ids)
    {
        return sjLjzjysyqkMapper.deleteSjLjzjysyqkByIds(ids);
    }

    /**
     * 删除邻井钻井液使用情况信息
     * 
     * @param id 邻井钻井液使用情况主键
     * @return 结果
     */
    @Override
    public int deleteSjLjzjysyqkById(Long id)
    {
        return sjLjzjysyqkMapper.deleteSjLjzjysyqkById(id);
    }
}
