package com.zjsgfa.project.zjsgfa.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.zjsgfa.framework.aspectj.lang.annotation.Log;
import com.zjsgfa.framework.aspectj.lang.enums.BusinessType;
import com.zjsgfa.project.zjsgfa.domain.SjLjzjysyqk;
import com.zjsgfa.project.zjsgfa.service.ISjLjzjysyqkService;
import com.zjsgfa.framework.web.controller.BaseController;
import com.zjsgfa.framework.web.domain.AjaxResult;
import com.zjsgfa.common.utils.poi.ExcelUtil;
import com.zjsgfa.framework.web.page.TableDataInfo;

/**
 * 邻井钻井液使用情况Controller
 * 
 * @author ruoyi
 * @date 2026-02-04
 */
@RestController
@RequestMapping("/system/sjLjzjysyqk")
public class SjLjzjysyqkController extends BaseController
{
    @Autowired
    private ISjLjzjysyqkService sjLjzjysyqkService;

    /**
     * 查询邻井钻井液使用情况列表
     */
    //@PreAuthorize("@ss.hasPermi('system:sjLjzjysyqk:list')")
    @GetMapping("/list")
    public TableDataInfo list(SjLjzjysyqk sjLjzjysyqk)
    {
        startPage();
        List<SjLjzjysyqk> list = sjLjzjysyqkService.selectSjLjzjysyqkList(sjLjzjysyqk);
        return getDataTable(list);
    }

    /**
     * 导出邻井钻井液使用情况列表
     */
    //@PreAuthorize("@ss.hasPermi('system:sjLjzjysyqk:export')")
    @Log(title = "邻井钻井液使用情况", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, SjLjzjysyqk sjLjzjysyqk)
    {
        List<SjLjzjysyqk> list = sjLjzjysyqkService.selectSjLjzjysyqkList(sjLjzjysyqk);
        ExcelUtil<SjLjzjysyqk> util = new ExcelUtil<SjLjzjysyqk>(SjLjzjysyqk.class);
        util.exportExcel(response, list, "邻井钻井液使用情况数据");
    }

    /**
     * 获取邻井钻井液使用情况详细信息
     */
    //@PreAuthorize("@ss.hasPermi('system:sjLjzjysyqk:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(sjLjzjysyqkService.selectSjLjzjysyqkById(id));
    }

    /**
     * 新增邻井钻井液使用情况
     */
    //@PreAuthorize("@ss.hasPermi('system:sjLjzjysyqk:add')")
    @Log(title = "邻井钻井液使用情况", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody SjLjzjysyqk sjLjzjysyqk)
    {
        return toAjax(sjLjzjysyqkService.insertSjLjzjysyqk(sjLjzjysyqk));
    }

    /**
     * 修改邻井钻井液使用情况
     */
    //@PreAuthorize("@ss.hasPermi('system:sjLjzjysyqk:edit')")
    @Log(title = "邻井钻井液使用情况", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody SjLjzjysyqk sjLjzjysyqk)
    {
        return toAjax(sjLjzjysyqkService.updateSjLjzjysyqk(sjLjzjysyqk));
    }

    /**
     * 删除邻井钻井液使用情况
     */
    //@PreAuthorize("@ss.hasPermi('system:sjLjzjysyqk:remove')")
    @Log(title = "邻井钻井液使用情况", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(sjLjzjysyqkService.deleteSjLjzjysyqkByIds(ids));
    }
}
